# -*- coding: utf-8 -*-
################################################################################
#
#  pyLOCSMS -- Python Interface to LOC Store Management Suite
#  Copyright © 2013-2015 Lance Edgar
#
#  This file is part of pyLOCSMS.
#
#  pyLOCSMS is free software: you can redistribute it and/or modify it under
#  the terms of the GNU General Public License as published by the Free
#  Software Foundation, either version 3 of the License, or (at your option)
#  any later version.
#
#  pyLOCSMS is distributed in the hope that it will be useful, but WITHOUT ANY
#  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
#  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
#  details.
#
#  You should have received a copy of the GNU General Public License along with
#  pyLOCSMS.  If not, see <http://www.gnu.org/licenses/>.
#
################################################################################
"""
Parsers for Document Exports

TODO: This whole module probably needs some to be renamed and refactored at
some point.  It satisfies a real-world need at the moment though.
"""

from __future__ import unicode_literals

import csv
import datetime
from decimal import Decimal


class Document(object):

    def __init__(self):
        self.details = []
        self.totals = []


class Header(object):
    pass


class Detail(object):
    pass


class Total(object):
    pass


class BuyingDocumentExportParser(object):

    def parse_store_number(self, csv_path):
        """
        Parse the store number (F1056) from the export file and return it.

        An export file generally contains many rows of data, each with a F1056
        value in the transaction header row.  This method assumes that all such
        values will match within a given file and therefore will only parse far
        enough to retrieve the first one.
        """
        with open(csv_path, 'rb') as f:
            reader = csv.reader(f)
            for row in reader:
                if row[0] == 'H':
                    header = self.parse_header(row)
                    return header.store_number

    def parse_export(self, csv_path):
        with open(csv_path, 'rb') as f:
            reader = csv.reader(f)
            documents = []
            doc = None
            for row in reader:
                if row[0] == 'H':
                    if doc:
                        documents.append(doc)
                    doc = Document()
                    doc.header = self.parse_header(row)
                elif row[0] == 'D':
                    doc.details.append(self.parse_detail(row))
                elif row[0] == 'T':
                    doc.totals.append(self.parse_total(row))
            documents.append(doc)
        return documents

    def int_(self, value):
        return int(value)

    def decimal(self, value):
        return Decimal(value)

    def date(self, value):
        return datetime.datetime.strptime(value, '%m/%d/%Y').date()

    def parse_header(self, row):
        header = Header()
        header.transaction_number = self.int_(row[1])
        header.vendor_id = row[2]
        header.date = self.date(row[3])
        header.vendor_name = row[4]
        header.store_number = row[6]
        header.mode = row[7]
        header.reference_number = row[8]
        return header

    def parse_detail(self, row):
        detail = Detail()
        detail.department_code = self.int_(row[4])
        detail.total_dollars = self.decimal(row[9])
        return detail

    def parse_total(self, row):
        total = Total()
        total.totalizer = self.int_(row[2])
        total.total_dollars = self.decimal(row[4])
        return total
